Crate pdk_lock_lib

Crate pdk_lock_lib 

PDK Lock Library

Primitives for coordinating work among Flex Gateway workers and policies. Generated locks expire automatically if not refreshed and are released on drop.

Primary types

Structs

Lock
This is a try lock that expires automatically if it was not refreshed before the expiration time. The lock is released on drop.
LockBuilder
Represents the base builder for a TryLock instance.
LockBuilderInstance
Represents a particular instance of a LockBuilder. It includes extra metadata of the policy, required to successfully work in all scenarios involving multiple policies.
TryLock
The built lock. Use this object’s try_lock to ensure mutual exclusion.