Lock

Struct Lock 

pub struct Lock<'a> { /* private fields */ }
This is a try lock that expires automatically if it was not refreshed before the expiration time. The lock is released on drop.

Implementations

Source

impl Lock<'_>

pub fn refresh_lock(&self) -> bool

Tries to update the remaining duration of the lock. Returns true if the refresh was successful or false if the lock was already taken by someone else