pub struct LockBuilder { /* private fields */ }Expand description
Represents the base builder for a TryLock instance.
Implementations
Sourceimpl LockBuilder
impl LockBuilder
Sourcepub fn new(&self, lock_id: String) -> LockBuilderInstance
pub fn new(&self, lock_id: String) -> LockBuilderInstance
Returns a LockBuilderInstance with an ID to uniquely identify the lock.
Note: if 2 locks are assigned the same ID in a same policy, they will share the state. This behavior is extended to other policies when using the shared lock option.