LockBuilderInstance

Struct LockBuilderInstance 

pub struct LockBuilderInstance { /* private fields */ }
Represents a particular instance of a LockBuilder. It includes extra metadata of the policy, required to successfully work in all scenarios involving multiple policies.

Implementations

Source

impl LockBuilderInstance

pub fn expiration(self, expiration: Duration) -> Self

Sets the time expiration time for the lock. An acquired lock will be considered lost once this time passes even if it was not released.

pub fn shared(self) -> Self

Indicates that the lock should not be isolated to the policy. The state will be shared across different policy instances and different policies that use the same lock ID.

pub fn build(self) -> TryLock

Builds a new TryLock with the corresponding specifications.