TryLock

Struct TryLock 

pub struct TryLock { /* private fields */ }
The built lock. Use this object’s try_lock to ensure mutual exclusion.

Implementations

Source

impl TryLock

pub fn try_lock(&self) -> Option<Lock<'_>>

Acquire the lock. Returns the lock if the lock was acquired, None if the lock is currently held by someone else or it is already owned by the current worker. The lock is released on drop.