pub struct Lock<'a> { /* private fields */ }Expand description
This is a try lock that expires automatically if it was not refreshed before the expiration time. The lock is released on drop.
Implementations