pub struct LockBuilderInstance { /* private fields */ }Expand description
Represents a particular instance of a LockBuilder. It includes extra metadata of the
policy, required to successfully work in all scenarios involving multiple policies.
Implementations
Sourceimpl LockBuilderInstance
impl LockBuilderInstance
Sourcepub fn expiration(self, expiration: Duration) -> Self
pub fn expiration(self, expiration: Duration) -> Self
Sets the time expiration time for the lock. An acquired lock will be considered lost once this time passes even if it was not released.
Indicates that the lock should not be isolated to the policy. The state will be shared across different policy instances and different policies that use the same lock ID.